@@ -113,7 +113,7 @@ int tcd_post_init( cd_struct *cd )
 int tcd_close_disc( cd_struct *cd )
 {
     debug("cdrom.c: tcd_close_disc(%p) top\n", cd );
-    close( cd->cd_dev );
+    close(cd->cd_dev);
     debug("cdrom.c: tcd_close_disc exiting normally\n" );
     return 0;
 }
@@ -179,11 +179,7 @@ int tcd_readtoc( cd_struct *cd )
 	    cd->trk[C(i)].toc.cdte_addr.msf.second;
 	cd->trk[C(i)].start = cd->trk[C(i)].length * 75 + 
 	    cd->trk[C(i)].toc.cdte_addr.msf.frame;
-		
-	/* Set up the default playlist */
-	cd->playlist[i] = i;
     }
-    cd->playlist[i] = -1;
 
     /* calculate track times */
     for(i = cd->first_t; i <= cd->last_t; i ++)
@@ -306,7 +302,6 @@ int tcd_playtracks(cd_struct *cd, int start_t, int end_t, int only_use_trkind)
     tcd_gettime(cd);
     if(cd->err) 
     {
-	cd->isdisk = FALSE;
 	/* try and inject cd */
 	tcd_ejectcd(cd);
 
@@ -380,7 +375,6 @@ int tcd_playtracks(cd_struct *cd, int start_t, int end_t, int only_use_trkind)
     }
 
     cd->isplayable = TRUE;
-    cd->isdisk = TRUE;
     debug("cdrom.c: tcd_playtracks exiting normally\n" );
     return tmp;
 }       
@@ -394,7 +388,6 @@ int tcd_play_seconds( cd_struct *cd, long int offset )
 
     cd->err = FALSE;
     cd->isplayable=FALSE;
-    cd->isdisk=FALSE;
 
     /* got subchannel? */
     msf.cdmsf_sec0 = cd->sc.cdsc_absaddr.msf.second+offset;
@@ -436,7 +429,6 @@ int tcd_play_seconds( cd_struct *cd, long int offset )
 	return(-1);
     }
     cd->isplayable=TRUE;                                                 
-    cd->isdisk=TRUE;
 
     debug("cdrom.c: tcd_playseconds exiting normally\n" );
     return tmp;
@@ -450,19 +442,16 @@ int tcd_ejectcd( cd_struct *cd )
     if(cd->isplayable) tcd_stopcd(cd);
     cd->err = FALSE;
 
-    if(cd->isdisk) 
+    if(!ioctl(cd->cd_dev, CDROMEJECT))
     {
-	ioctl( cd->cd_dev, CDROMEJECT );
-	cd->isdisk = FALSE;
 	cd->isplayable = FALSE;
-	strcpy( cd->errmsg, "No disc in drive " );
+	strcpy(cd->errmsg, "No disc in drive ");
 	cd->err = TRUE;
     } 
     else 
     {
 #ifdef CDROMCLOSETRAY
 	tmp = ioctl( cd->cd_dev, CDROMCLOSETRAY );
-	cd->isdisk = TRUE;
 #endif
 
 	if(tcd_post_init(cd))
@@ -475,8 +464,6 @@ int tcd_ejectcd( cd_struct *cd )
 
 	    return(-1);
 	}
-
-	cd->isdisk = TRUE;
 	cd->isplayable = TRUE;
     }
     cd->cur_t = 0;	
@@ -557,7 +544,6 @@ void tcd_opencddev( cd_struct *cd, WarnFunc msg_cb )
 {
     char tmp[256];
     cd->err = FALSE;
-    cd->isdisk=FALSE;
 
     if(cd->cd_dev > 0) /* SDH rvs test (was < should be > ) */
 	close(cd->cd_dev);
@@ -575,7 +561,6 @@ void tcd_opencddev( cd_struct *cd, WarnFunc msg_cb )
 	cd->err = TRUE;
 	return;
     }
-    cd->isdisk=TRUE;
 }
 
 void parse_dtitle(cd_struct *cd)
